@@ -21,12 +21,15 @@ else:
 
 __all__ = (
     "HandlerErrorCodeType",
+    "ListResourceRequestsPaginatorName",
+    "ListResourcesPaginatorName",
     "OperationStatusType",
     "OperationType",
     "ResourceRequestSuccessWaiterName",
     "CloudControlApiServiceName",
     "ServiceName",
     "ResourceServiceName",
+    "PaginatorName",
     "WaiterName",
     "RegionName",
 )
@@ -49,6 +52,8 @@ HandlerErrorCodeType = Literal[
     "ServiceTimeout",
     "Throttling",
 ]
+ListResourceRequestsPaginatorName = Literal["list_resource_requests"]
+ListResourcesPaginatorName = Literal["list_resources"]
 OperationStatusType = Literal[
     "CANCEL_COMPLETE", "CANCEL_IN_PROGRESS", "FAILED", "IN_PROGRESS", "PENDING", "SUCCESS"
 ]
@@ -92,6 +97,7 @@ ServiceName = Literal[
     "ce",
     "chime",
     "chime-sdk-identity",
+    "chime-sdk-media-pipelines",
     "chime-sdk-meetings",
     "chime-sdk-messaging",
     "cloud9",
@@ -207,6 +213,7 @@ ServiceName = Literal[
     "iottwinmaker",
     "iotwireless",
     "ivs",
+    "ivschat",
     "kafka",
     "kafkaconnect",
     "kendra",
@@ -372,6 +379,7 @@ ResourceServiceName = Literal[
     "sns",
     "sqs",
 ]
+PaginatorName = Literal["list_resource_requests", "list_resources"]
 WaiterName = Literal["resource_request_success"]
 RegionName = Literal[
     "af-south-1",
