@@ -35,10 +35,13 @@ __all__ = (
     "GetResourceRequestStatusInputRequestTypeDef",
     "GetResourceRequestStatusInputResourceRequestSuccessWaitTypeDef",
     "GetResourceRequestStatusOutputTypeDef",
+    "ListResourceRequestsInputListResourceRequestsPaginateTypeDef",
     "ListResourceRequestsInputRequestTypeDef",
     "ListResourceRequestsOutputTypeDef",
+    "ListResourcesInputListResourcesPaginateTypeDef",
     "ListResourcesInputRequestTypeDef",
     "ListResourcesOutputTypeDef",
+    "PaginatorConfigTypeDef",
     "ProgressEventTypeDef",
     "ResourceDescriptionTypeDef",
     "ResourceRequestStatusFilterTypeDef",
@@ -196,6 +199,15 @@ GetResourceRequestStatusOutputTypeDef = TypedDict(
     },
 )
 
+ListResourceRequestsInputListResourceRequestsPaginateTypeDef = TypedDict(
+    "ListResourceRequestsInputListResourceRequestsPaginateTypeDef",
+    {
+        "ResourceRequestStatusFilter": "ResourceRequestStatusFilterTypeDef",
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
 ListResourceRequestsInputRequestTypeDef = TypedDict(
     "ListResourceRequestsInputRequestTypeDef",
     {
@@ -215,6 +227,31 @@ ListResourceRequestsOutputTypeDef = TypedDict(
     },
 )
 
+_RequiredListResourcesInputListResourcesPaginateTypeDef = TypedDict(
+    "_RequiredListResourcesInputListResourcesPaginateTypeDef",
+    {
+        "TypeName": str,
+    },
+)
+_OptionalListResourcesInputListResourcesPaginateTypeDef = TypedDict(
+    "_OptionalListResourcesInputListResourcesPaginateTypeDef",
+    {
+        "TypeVersionId": str,
+        "RoleArn": str,
+        "ResourceModel": str,
+        "PaginationConfig": "PaginatorConfigTypeDef",
+    },
+    total=False,
+)
+
+
+class ListResourcesInputListResourcesPaginateTypeDef(
+    _RequiredListResourcesInputListResourcesPaginateTypeDef,
+    _OptionalListResourcesInputListResourcesPaginateTypeDef,
+):
+    pass
+
+
 _RequiredListResourcesInputRequestTypeDef = TypedDict(
     "_RequiredListResourcesInputRequestTypeDef",
     {
@@ -250,6 +287,16 @@ ListResourcesOutputTypeDef = TypedDict(
     },
 )
 
+PaginatorConfigTypeDef = TypedDict(
+    "PaginatorConfigTypeDef",
+    {
+        "MaxItems": int,
+        "PageSize": int,
+        "StartingToken": str,
+    },
+    total=False,
+)
+
 ProgressEventTypeDef = TypedDict(
     "ProgressEventTypeDef",
     {
